@@ -4,6 +4,8 @@ Provides a configured logger for the application.
 
 __all__ = ["logger"]
 
+from pathlib import Path
+
 from loguru import logger
 
-logger.add("scoach.log")
+logger.add(Path.home() / "scoach.log")
